import "package:flutter/material.dart";
import "package:flutter_feedback/flutter_feedback.dart";

///
class FlutterFeedbackEntryWidget extends StatelessWidget {
  ///
  const FlutterFeedbackEntryWidget({
    this.feedbackService,
    this.translations,
    this.configuration,
    this.icon = Icons.reviews,
    this.iconColor = Colors.black,
    this.backgroundColor = Colors.grey,
    this.widgetSize = 50,
    this.onTap,
    super.key,
  });

  /// The chat service associated with the widget.
  final FeedbackService? feedbackService;

  ///
  final FeedbackTranslations? translations;

  ///
  final FeedbackConfiguration? configuration;

  /// Background color of the widget.
  final Color backgroundColor;

  /// Size of the widget.
  final double widgetSize;

  /// Callback function triggered when the widget is tapped.
  final VoidCallback? onTap;

  /// Icon to be displayed.
  final IconData icon;

  /// Color of the icon.
  final Color iconColor;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () async =>
          onTap?.call ??
          Navigator.of(context).push(
            MaterialPageRoute(
              builder: (context) => FlutterFeedbackNavigatorUserstory(
                feedbackService: feedbackService,
                configuration: configuration,
                translations: translations,
              ),
            ),
          ),
      child: Container(
        width: widgetSize,
        height: widgetSize,
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          color: backgroundColor,
        ),
        child: Icon(
          icon,
          color: iconColor,
          size: widgetSize / 1.5,
        ),
      ),
    );
  }
}
