import "package:flutter/material.dart";
import "package:flutter_feedback/flutter_feedback.dart";
import "package:flutter_feedback/src/screens/about_us.dart";
import "package:flutter_feedback/src/screens/report_issue.dart";
import "package:in_app_review/in_app_review.dart";
import "package:url_launcher/url_launcher.dart";

///
class FlutterFeedbackNavigatorUserstory extends StatefulWidget {
  ///
  const FlutterFeedbackNavigatorUserstory({
    this.feedbackService,
    this.configuration,
    this.translations,
    super.key,
  });

  ///
  final FeedbackService? feedbackService;

  ///
  final FeedbackConfiguration? configuration;

  ///
  final FeedbackTranslations? translations;

  @override
  State<FlutterFeedbackNavigatorUserstory> createState() =>
      _FlutterFeedbackNavigatorUserstoryState();
}

class _FlutterFeedbackNavigatorUserstoryState
    extends State<FlutterFeedbackNavigatorUserstory> {
  late FeedbackService feedbackService;
  late FeedbackConfiguration configuration;
  late FeedbackTranslations translations;

  @override
  void initState() {
    feedbackService = widget.feedbackService ?? FeedbackService();
    configuration = widget.configuration ?? const FeedbackConfiguration();
    translations = widget.translations ?? const FeedbackTranslations.empty();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return aboutPage();
  }

  Widget aboutPage() {
    var hasPrivacyControls = configuration.privacyPolicyControls != null;
    var hasTermsControls = configuration.termsOfServiceControls != null;
    var hasFeedbackControls = configuration.feedbackControls != null;
    return AboutPage(
      translations: translations,
      configuration: configuration,
      onReportIssue: (report) async {
        await feedbackService.sendReport(report: report);
      },
      onFeedback: (report) async {
        await feedbackService.sendFeedback(feedback: report);
      },
      onTapPrivacyPolicy: hasPrivacyControls
          ? null
          : () async {
              if (configuration.onTapPrivacyPolicy != null) {
                configuration.onTapPrivacyPolicy!();
                return;
              }
              await _launchUrl(Uri.parse(configuration.privacyPolicyUrl));
            },
      onTapTermsOfService: hasTermsControls
          ? null
          : () async {
              if (configuration.onTapTermsOfService != null) {
                configuration.onTapTermsOfService!();
                return;
              }

              await _launchUrl(Uri.parse(configuration.termsOfServiceUrl));
            },
      onTapFeedback: hasFeedbackControls
          ? null
          : configuration.onTapFeedback ??
              () async {
                await showFeedbackBottomSheet(
                  context: context,
                  onFeedback: (report) async {
                    await feedbackService.sendFeedback(feedback: report);
                  },
                  onGoodRating: configuration.useStoreReview
                      ? () async {
                          await InAppReview.instance.openStoreListing(
                            appStoreId: configuration.appStoreId,
                          );
                        }
                      : null,
                );
              },
      onTapAboutUs: configuration.onTapAboutUs,
      aboutUsControls: configuration.aboutUsControls ??
          [
            aboutUsScreen(),
          ],
      feedbackControls: configuration.feedbackControls ?? [],
      reportIssieControls: configuration.reportIssueControls ??
          [
            reportIssueScreen(),
          ],
    );
  }

  Control aboutUsScreen() {
    return aboutUs(
      translations: translations,
    );
  }

  Control reportIssueScreen() {
    return reportIssue(
      context: context,
      translations: translations,
      configuration: configuration,
      onReportIssue: (report) async {
        await feedbackService.sendReport(report: report);
      },
    );
  }
}

Future<void> _launchUrl(Uri url) async {
  if (!await launchUrl(url)) {
    throw Exception("Could not launch $url");
  }
}
