import "package:flutter/material.dart";
import "package:flutter_feedback/flutter_feedback.dart";
import "package:flutter_feedback/src/widgets/about_footer.dart";

///
class AboutPage extends StatefulWidget {
  ///
  const AboutPage({
    required this.onReportIssue,
    required this.onFeedback,
    required this.aboutUsControls,
    required this.translations,
    required this.configuration,
    required this.onTapPrivacyPolicy,
    required this.onTapTermsOfService,
    required this.onTapAboutUs,
    required this.feedbackControls,
    required this.reportIssieControls,
    required this.onTapFeedback,
    super.key,
  });

  ///
  final FeedbackTranslations translations;

  ///
  final FeedbackConfiguration configuration;

  ///
  final Future<void> Function(Report report) onReportIssue;

  ///
  final Future<void> Function(Report report) onFeedback;

  ///
  final Function()? onTapAboutUs;

  ///
  final List<Control> aboutUsControls;

  ///
  final List<Control> feedbackControls;

  ///
  final List<Control> reportIssieControls;

  ///
  final VoidCallback? onTapPrivacyPolicy;

  ///
  final VoidCallback? onTapTermsOfService;

  ///
  final VoidCallback? onTapFeedback;

  @override
  State<AboutPage> createState() => _AboutPageState();
}

class _AboutPageState extends State<AboutPage> {
  @override
  Widget build(BuildContext context) {
    var translations = widget.translations;
    var configuration = widget.configuration;

    return Scaffold(
      resizeToAvoidBottomInset: false,
      appBar: AppBar(
        title: Text(translations.feedbackTitle),
      ),
      body: SafeArea(
        child: SingleChildScrollView(
          child: Column(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              DeviceSettingsPage(
                settings: [
                  if (configuration.useAbout) ...[
                    Control.group(
                      title: translations.about,
                      settings: [
                        Control.page(
                          title: translations.aboutUs,
                          controls: widget.aboutUsControls,
                          onTap: widget.onTapAboutUs,
                          capitalizeFirstLetter: false,
                        ),
                        Control.page(
                          title: translations.privacyPolicy,
                          controls: configuration.privacyPolicyControls ?? [],
                          onTap: widget.onTapPrivacyPolicy,
                        ),
                        Control.page(
                          title: translations.termsOfService,
                          controls: configuration.termsOfServiceControls ?? [],
                          onTap: widget.onTapTermsOfService,
                        ),
                      ],
                    ),
                  ],
                  if (configuration.useFeedback) ...[
                    Control.group(
                      title: translations.feedback,
                      settings: [
                        Control.page(
                          title: translations.giveUsFeedback,
                          controls: widget.feedbackControls,
                          onTap: widget.onTapFeedback,
                        ),
                        Control.page(
                          title: translations.reportIssue,
                          controls: widget.reportIssieControls,
                          onTap: configuration.onTapReportIssue,
                          capitalizeFirstLetter: false,
                        ),
                      ],
                    ),
                  ],
                ],
              ),
              Center(
                child: AboutFooter(
                  configuration: configuration,
                  versiontranslation: translations.version,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
