import "package:device_info_plus/device_info_plus.dart";
import "package:flutter/material.dart";
import "package:flutter_feedback/flutter_feedback.dart";
import "package:flutter_feedback/src/widgets/default_filled_button.dart";
import "package:flutter_feedback/src/widgets/issue_category_selecter.dart";
import "package:package_info_plus/package_info_plus.dart";

///
Control reportIssue({
  required BuildContext context,
  required FeedbackTranslations translations,
  required FeedbackConfiguration configuration,
  required Future<void> Function(Report report) onReportIssue,
}) {
  var theme = Theme.of(context);
  var issue = ValueNotifier<String?>(null);
  var formKey = GlobalKey<FormState>();
  var issueExplenationController = TextEditingController();
  return Control.custom(
    key: "report_issue_page",
    content: SizedBox(
      height: MediaQuery.of(context).size.height * 0.8,
      child: Padding(
        padding: const EdgeInsets.only(top: 20, left: 20, right: 20),
        child: CustomScrollView(
          slivers: [
            SliverList(
              delegate: SliverChildListDelegate([
                Text(
                  translations.reportIssueDescription,
                  style: theme.textTheme.bodyMedium,
                ),
                if (configuration.selectIssueCategory) ...[
                  const SizedBox(
                    height: 20,
                  ),
                  Padding(
                    padding: const EdgeInsets.symmetric(
                      horizontal: 2,
                    ),
                    child: Text(
                      translations.selectIssueTitle,
                      style: theme.textTheme.titleMedium,
                    ),
                  ),
                  IssueCategorySelecter(
                    translations: translations,
                    onCategorySelected: (value) {
                      issue.value = value;
                    },
                  ),
                ],
                const SizedBox(
                  height: 20,
                ),
                Padding(
                  padding: const EdgeInsets.symmetric(
                    horizontal: 12,
                  ),
                  child: Text(
                    translations.reportTextfieldHeaderText,
                    style: theme.textTheme.titleMedium,
                  ),
                ),
                const SizedBox(
                  height: 4,
                ),
                Padding(
                  padding: const EdgeInsets.symmetric(
                    horizontal: 12,
                  ),
                  child: Form(
                    key: formKey,
                    child: TextFormField(
                      textInputAction: TextInputAction.done,
                      controller: issueExplenationController,
                      expands: false,
                      maxLines: 5,
                      minLines: null,
                      decoration: InputDecoration(
                        filled: true,
                        fillColor: Colors.white,
                        contentPadding: const EdgeInsets.all(
                          16,
                        ),
                        hintStyle: theme.textTheme.bodySmall?.copyWith(
                          color: theme.textTheme.bodySmall?.color
                              ?.withOpacity(0.5),
                        ),
                        hintText: translations.reportHintText,
                        focusedBorder: const OutlineInputBorder(
                          borderRadius: BorderRadius.all(
                            Radius.circular(
                              16,
                            ),
                          ),
                          borderSide: BorderSide(
                            color: Colors.transparent,
                            width: 0,
                          ),
                        ),
                        enabledBorder: const OutlineInputBorder(
                          borderRadius: BorderRadius.all(
                            Radius.circular(
                              16,
                            ),
                          ),
                          borderSide: BorderSide(
                            color: Colors.transparent,
                            width: 0,
                          ),
                        ),
                      ),
                      validator: (value) {
                        if (value == null || value.isEmpty) {
                          return translations.feedbackValidationMessage;
                        }
                        return null;
                      },
                      onChanged: (value) {},
                    ),
                  ),
                ),
              ]),
            ),
            SliverFillRemaining(
              hasScrollBody: false,
              fillOverscroll: true,
              child: Align(
                alignment: Alignment.bottomCenter,
                child: Padding(
                  padding: const EdgeInsets.symmetric(
                    horizontal: 80,
                  ),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      if (configuration.selectIssueCategory) ...[
                        ValueListenableBuilder(
                          valueListenable: issue,
                          builder: (context, value, widget) {
                            return Opacity(
                              opacity: value != null ? 1 : 0.5,
                              child: DefaultButton(
                                buttonText: translations.reportButtonText,
                                onPressed: () async {
                                  if (value == null) {
                                    return;
                                  }
                                  var packageInfo =
                                      await PackageInfo.fromPlatform();
                                  var deviceInfo =
                                      await DeviceInfoPlugin().deviceInfo;
                                  var report = Report(
                                    appVersion: packageInfo.version,
                                    deviceModel: deviceInfo.data["name"],
                                    osVersion: deviceInfo.data["systemVersion"],
                                    issue: value,
                                    issueExplanation:
                                        issueExplenationController.text,
                                  );
                                  await onReportIssue(report);
                                  issueExplenationController.clear();
                                  if (context.mounted) {
                                    Navigator.of(context).pop();
                                  }
                                },
                              ),
                            );
                          },
                        ),
                      ] else ...[
                        DefaultButton(
                          buttonText: translations.reportButtonText,
                          onPressed: () async {
                            if (formKey.currentState!.validate()) {
                              var packageInfo =
                                  await PackageInfo.fromPlatform();
                              var deviceInfo =
                                  await DeviceInfoPlugin().deviceInfo;
                              var report = Report(
                                appVersion: packageInfo.version,
                                deviceModel: deviceInfo.data["name"],
                                osVersion: deviceInfo.data["systemVersion"],
                                issueExplanation:
                                    issueExplenationController.text,
                              );
                              await onReportIssue(report);
                              issueExplenationController.clear();
                              if (context.mounted) {
                                Navigator.of(context).pop();
                              }
                            }
                          },
                        ),
                      ],
                    ],
                  ),
                ),
              ),
            ),
          ],
        ),
      ),
    ),
  );
}
